@@ -94,6 +94,13 @@ sub Odrmaa_wait {
     if ($ret[0] == $DRMAA_ERRNO_EXIT_TIMEOUT) {
         $ret[0] = $DRMAA_ERRNO_SUCCESS;
         $ret[1] = undef;
+    }
+	else {
+		$ret[1] .= ': ** THIS IS USUALLY A TIMING ERROR IN THE DRMAA LIBRARY'
+	            .  ' INTERACTION WITH SGE. TRY RE-RUNNING THE PROGRAM. IT'
+				.  ' WILL USUALLY WORK CORRECTLY **'
+			if defined $ret[1]
+		       and $ret[1] =~ /no usage information was returned for the completed job$/;
     }
     dt( @ret );
 }
